@@ -55,14 +55,16 @@ use {
   
     let provider_fee = use_invalidator.extension_payment_amount.unwrap() * (PROVIDER_FEE / FEE_SCALE);
     let recipient_fee = use_invalidator.extension_payment_amount.unwrap() * (RECIPIENT_FEE / FEE_SCALE);
-    let cpi_accounts = Transfer {
-        from: ctx.accounts.payer_token_account.to_account_info(),
-        to: ctx.accounts.payment_manager_token_account.to_account_info(),
-        authority: ctx.accounts.payer.to_account_info(),
-    };
-    let cpi_program = ctx.accounts.token_program.to_account_info();
-    let cpi_context = CpiContext::new(cpi_program, cpi_accounts);
-    token::transfer(cpi_context, provider_fee + recipient_fee)?;
+    if provider_fee + recipient_fee > 0 {
+      let cpi_accounts = Transfer {
+          from: ctx.accounts.payer_token_account.to_account_info(),
+          to: ctx.accounts.payment_manager_token_account.to_account_info(),
+          authority: ctx.accounts.payer.to_account_info(),
+      };
+      let cpi_program = ctx.accounts.token_program.to_account_info();
+      let cpi_context = CpiContext::new(cpi_program, cpi_accounts);
+      token::transfer(cpi_context, provider_fee + recipient_fee)?;
+    }
   
     let cpi_accounts = Transfer {
       from: ctx.accounts.payer_token_account.to_account_info(),
